@@ -145,7 +145,7 @@ struct State
 		for (size_t i=0; i<m_sheetZoneIdList.size(); ++i)
 			zoneIdToSheetMap[m_sheetZoneIdList[i]]=int(i);
 		std::map<int,int> res;
-		for (auto it : m_dataZoneIdToSheetZoneIdMap)
+		for (auto const &it : m_dataZoneIdToSheetZoneIdMap)
 		{
 			if (zoneIdToSheetMap.find(it.second)==zoneIdToSheetMap.end())
 			{
