@@ -38,6 +38,8 @@ class Cell;
 class Spreadsheet;
 struct Style;
 struct State;
+struct Table123Styles;
+class SubDocument;
 }
 
 class LotusParser;
@@ -51,6 +53,7 @@ class LotusSpreadsheet
 {
 public:
 	friend class LotusParser;
+	friend class LotusSpreadsheetInternal::SubDocument;
 
 	//! constructor
 	explicit LotusSpreadsheet(LotusParser &parser);
@@ -80,16 +83,20 @@ protected:
 
 	//! send the data
 	void sendSpreadsheet(int sheetId);
+	//! returns the name of the id's spreadsheet
+	librevenge::RVNGString getSheetName(int id) const;
 
 	/** send the cell data in a row
 
 	 \note this function does not call openSheetRow, closeSheetRow*/
-	void sendRowContent(LotusSpreadsheetInternal::Spreadsheet const &sheet, int row);
+	void sendRowContent(LotusSpreadsheetInternal::Spreadsheet const &sheet, int row, LotusSpreadsheetInternal::Table123Styles const *table123Styles);
 	//! send the cell data
 	void sendCellContent(LotusSpreadsheetInternal::Cell const &cell,
 	                     LotusSpreadsheetInternal::Style const &style, int numRepeated=1);
 	//! try to send a formated text
 	void sendText(RVNGInputStreamPtr &input, long endPos, LotusSpreadsheetInternal::Style const &style) const;
+	//! try to send a note
+	void sendTextNote(RVNGInputStreamPtr &input, WPSEntry const &entry) const;
 
 	//////////////////////// report //////////////////////////////
 
@@ -99,37 +106,39 @@ protected:
 	//////////////////////// spread sheet //////////////////////////////
 
 	//! reads a sheet name: zone 0x23
-	bool readSheetName(shared_ptr<WPSStream> stream);
+	bool readSheetName(std::shared_ptr<WPSStream> stream);
 	//! reads a sheet name: zone 0x1b 36b0
-	bool readSheetName1B(shared_ptr<WPSStream> stream, long endPos);
+	bool readSheetName1B(std::shared_ptr<WPSStream> stream, long endPos);
 
+	//! reads a cell zone formats: zone 801, lotus 123
+	bool readCellsFormat801(std::shared_ptr<WPSStream> stream, WPSVec3i const &minC, WPSVec3i const &maxC, int typeZone);
 	//! reads the columns definitions
-	bool readColumnDefinition(shared_ptr<WPSStream> stream);
+	bool readColumnDefinition(std::shared_ptr<WPSStream> stream);
 	//! reads the column sizes ( in char )
-	bool readColumnSizes(shared_ptr<WPSStream> stream);
+	bool readColumnSizes(std::shared_ptr<WPSStream> stream);
 	//! reads the row formats
-	bool readRowFormats(shared_ptr<WPSStream> stream);
+	bool readRowFormats(std::shared_ptr<WPSStream> stream);
 	//! reads a cell's row format
-	bool readRowFormat(shared_ptr<WPSStream> stream, LotusSpreadsheetInternal::Style &style, int &numCell, long endPos);
+	bool readRowFormat(std::shared_ptr<WPSStream> stream, LotusSpreadsheetInternal::Style &style, int &numCell, long endPos);
 	//! reads the row size ( in pt*32 )
-	bool readRowSizes(shared_ptr<WPSStream> stream, long endPos);
+	bool readRowSizes(std::shared_ptr<WPSStream> stream, long endPos);
 
 	//! reads a cell
-	bool readCell(shared_ptr<WPSStream> stream);
+	bool readCell(std::shared_ptr<WPSStream> stream);
 	//! reads a cell or list of cell name
-	bool readCellName(shared_ptr<WPSStream> stream);
+	bool readCellName(std::shared_ptr<WPSStream> stream);
 
 	// in fmt
 
 	//! try to read a sheet header: 0xc3
-	bool readSheetHeader(shared_ptr<WPSStream> stream);
+	bool readSheetHeader(std::shared_ptr<WPSStream> stream);
 	//! try to read an extra row format: 0xc5
-	bool readExtraRowFormats(shared_ptr<WPSStream> stream);
+	bool readExtraRowFormats(std::shared_ptr<WPSStream> stream);
 
 	// in zone 0x1b
 
 	//! try to read a note: subZone id 9065
-	bool readNote(shared_ptr<WPSStream> stream, long endPos);
+	static bool readNote(std::shared_ptr<WPSStream> stream, long endPos);
 
 	// data in formula
 
@@ -138,19 +147,20 @@ protected:
 	/* reads a formula */
 	bool readFormula(WPSStream &stream, long endPos, int sId, bool newFormula,
 	                 std::vector<WKSContentListener::FormulaInstruction> &formula, std::string &error);
-
+	/* try to parse a variable data */
+	static bool parseVariable(std::string const &variable, WKSContentListener::FormulaInstruction &instr);
 	//! small debug function used to print text with format sequence
 	static std::string getDebugStringForText(std::string const &text);
 private:
-	LotusSpreadsheet(LotusSpreadsheet const &orig);
-	LotusSpreadsheet &operator=(LotusSpreadsheet const &orig);
-	shared_ptr<WKSContentListener> m_listener; /** the listener (if set)*/
+	LotusSpreadsheet(LotusSpreadsheet const &orig) = delete;
+	LotusSpreadsheet &operator=(LotusSpreadsheet const &orig) = delete;
+	std::shared_ptr<WKSContentListener> m_listener; /** the listener (if set)*/
 	//! the main parser
 	LotusParser &m_mainParser;
 	//! the style manager
-	shared_ptr<LotusStyleManager> m_styleManager;
+	std::shared_ptr<LotusStyleManager> m_styleManager;
 	//! the internal state
-	shared_ptr<LotusSpreadsheetInternal::State> m_state;
+	std::shared_ptr<LotusSpreadsheetInternal::State> m_state;
 };
 
 #endif /* LOTUS_SPREAD_SHEET_H */
