@@ -84,7 +84,7 @@ struct State
 	//! try to retrieve a color
 	bool getColor(int id, WPSColor &col) const
 	{
-		static WPSColor colors[16]=
+		static WPSColor const colors[16]=
 		{
 			WPSColor(0,0,0), WPSColor(128,128,128), WPSColor(192,192,192), WPSColor(255,255,255),
 			WPSColor(255,0,0), WPSColor(0,255,0), WPSColor(0,0,255), WPSColor(0,255,255),
@@ -614,8 +614,6 @@ bool PocketWordParser::sendParagraph(size_t paraId)
 		{
 			switch (val)
 			{
-			case 0:
-				break;
 			case 1:
 				para.m_justify=libwps::JustificationRight;
 				break;
