@@ -257,7 +257,7 @@ public:
 				return m_cell.valid();
 			if (m_contentType!=C_Text)
 				return false;
-			for (auto &e : m_textEntryList)
+			for (auto const &e : m_textEntryList)
 			{
 				if (e.valid()) return true;
 			}
