@@ -506,7 +506,7 @@ bool WPS8Parser::sendTable(Vec2f const &size, int objectId)
 		return false;
 	}
 
-	auto const &frame = m_state->m_frameList[(size_t)pos->second];
+	auto const &frame = m_state->m_frameList[size_t(pos->second)];
 	if (frame.m_idStrs < 0)
 	{
 		WPS_DEBUG_MSG(("WPS8Parser:sendTable can not find the text zone \n"));
@@ -534,7 +534,7 @@ int WPS8Parser::getTableSTRSId(int tableId) const
 	// probably ok: checkme
 	if (pos == m_state->m_table2FrameMap.end())
 		return -1;
-	auto const &frame = m_state->m_frameList[(size_t)pos->second];
+	auto const &frame = m_state->m_frameList[size_t(pos->second)];
 	if (frame.m_idStrs < 0)
 	{
 		WPS_DEBUG_MSG(("WPS8Parser:getTableSTRSId can not find the text zone \n"));
@@ -691,8 +691,8 @@ bool WPS8Parser::createStructures()
 	{
 		WPS8ParserInternal::Frame const &frame = m_state->m_frameList[i];
 		if (frame.m_idObject < 0) continue;
-		m_state->m_object2FrameMap[frame.m_idObject] = (int) i;
-		m_state->m_table2FrameMap[frame.m_idTable] = (int) i;
+		m_state->m_object2FrameMap[frame.m_idObject] = int(i);
+		m_state->m_table2FrameMap[frame.m_idTable] = int(i);
 	}
 
 	m_graphParser->computePositions();
@@ -836,7 +836,7 @@ bool WPS8Parser::parseHeaderIndexEntry()
 
 		if (c != 0 && c != 0x20 && (41 > c || c > 90))
 		{
-			WPS_DEBUG_MSG(("WPS8Parser::parseHeaderIndexEntry: error: bad character=%u (0x%02x) in name in header index\n", (unsigned)c, (unsigned)c));
+			WPS_DEBUG_MSG(("WPS8Parser::parseHeaderIndexEntry: error: bad character=%u (0x%02x) in name in header index\n", unsigned(c), unsigned(c)));
 			ascii().addNote("###IndexEntry bad name(ignored)");
 
 			input->seek(pos + cch, librevenge::RVNG_SEEK_SET);
@@ -846,25 +846,25 @@ bool WPS8Parser::parseHeaderIndexEntry()
 
 	f << "Entries("<<name<<")";
 	if (cch != 24) f << ", #size=" << int(cch);
-	auto id = (int) libwps::readU16(input);
+	auto id = int(libwps::readU16(input));
 	f << ", id=" << id << ", (";
 	for (i = 0; i < 2; i ++)
 	{
-		auto val = (int) libwps::read16(input);
+		auto val = int(libwps::read16(input));
 		f << val << ",";
 	}
 
 	std::string name2;
 	for (i =0; i < 4; i++)
-		name2.append(1, (char) libwps::readU8(input));
+		name2.append(1, char(libwps::readU8(input)));
 	f << "), " << name2;
 
 	WPSEntry hie;
 	hie.setName(name);
 	hie.setType(name2);
 	hie.setId(id);
-	hie.setBegin((long) libwps::readU32(input));
-	hie.setLength((long) libwps::readU32(input));
+	hie.setBegin(long(libwps::readU32(input)));
+	hie.setLength(long(libwps::readU32(input)));
 
 	f << ", offset=" << std::hex << hie.begin() << ", length=" << hie.length();
 
@@ -911,7 +911,7 @@ bool WPS8Parser::parseHeaderIndexEntryEnd(long endPos, WPSEntry &hie, std::strin
 	long len = endPos-pos;
 	libwps::DebugStream f;
 
-	auto size = (int) libwps::read16(input);
+	auto size = int(libwps::read16(input));
 	librevenge::RVNGString str;
 	if (2*(size+1) != len || !m_textParser->readString(input, 2*size, str))
 	{
@@ -940,8 +940,8 @@ bool WPS8Parser::parseHeaderIndex()
 	input->seek(0x08, librevenge::RVNG_SEEK_SET);
 
 	long pos = input->tell();
-	auto i0 = (int) libwps::read16(input);
-	auto i1 = (int) libwps::read16(input);
+	auto i0 = int(libwps::read16(input));
+	auto i1 = int(libwps::read16(input));
 	uint16_t n_entries = libwps::readU16(input);
 	// fixme: sanity check n_entries
 
@@ -999,12 +999,12 @@ bool WPS8Parser::parseHeaderIndex()
 		if (0xFFFFFFFF == next_index_table && n_entries > 0)
 		{
 			WPS_DEBUG_MSG(("WPS8Parser::parseHeaderIndex: error: expected more header index entries\n"));
-			return n_entries > 0;
+			return true;
 		}
 
 		if (0xFFFFFFFF == next_index_table)	break;
 
-		if (input->seek((long) next_index_table, librevenge::RVNG_SEEK_SET) != 0) return readSome;
+		if (input->seek(long(next_index_table), librevenge::RVNG_SEEK_SET) != 0) return readSome;
 	}
 	while (n_entries > 0);
 
@@ -1033,7 +1033,7 @@ bool WPS8Parser::readDocProperties(WPSEntry const &entry, WPSPageSpan &page)
 
 	if (length < 2)
 	{
-		WPS_DEBUG_MSG(("WPS8Parser::readDocProperties: warning: DOP length=0x%lx\n", (unsigned long) length));
+		WPS_DEBUG_MSG(("WPS8Parser::readDocProperties: warning: DOP length=0x%lx\n", static_cast<unsigned long>(length)));
 		return false;
 	}
 
@@ -1070,7 +1070,7 @@ bool WPS8Parser::readDocProperties(WPSEntry const &entry, WPSPageSpan &page)
 		// is dt.id()==6 another dimension ?
 		if (dt.id() >= 0 && (dt.id() < 6 || dt.id()==7))
 		{
-			dim[dt.id()] = float(dt.m_value)/914400.f;
+			dim[dt.id()] = double(dt.m_value)/914400;
 			setVal[dt.id()] = true;
 			continue;
 		}
@@ -1100,7 +1100,7 @@ bool WPS8Parser::readDocProperties(WPSEntry const &entry, WPSPageSpan &page)
 			}
 			break;
 		case 0x1b:   // [-1,0,1,3,4]
-			f2 << "f" << dt.id() << "=" << (int) int8_t(dt.m_value) << ",";
+			f2 << "f" << dt.id() << "=" << int(int8_t(dt.m_value)) << ",";
 			break;
 		case 0x13:   // an entries index, always an IBGF ?
 			m_state->m_background.setName(dt.m_text);
@@ -1161,7 +1161,7 @@ bool WPS8Parser::readDocProperties(WPSEntry const &entry, WPSPageSpan &page)
 					break;
 				}
 				elt++;
-				str += (char) val;
+				str += char(val);
 			}
 			if (!str.length())
 			{
@@ -1175,7 +1175,7 @@ bool WPS8Parser::readDocProperties(WPSEntry const &entry, WPSPageSpan &page)
 			elt=0;
 			while (elt++ < numElt)
 			{
-				auto val = (long) libwps::readU16(input);
+				auto val = long(libwps::readU16(input));
 				if (val) f2 << "f" << elt << "=" << std::hex << val << std::dec << ",";
 			}
 			f2 << "],";
@@ -1202,7 +1202,7 @@ bool WPS8Parser::readDocProperties(WPSEntry const &entry, WPSPageSpan &page)
 			f2 << "unk" << std::hex << dt.id() << "=" << "[";
 			for (int i = 0; i < 128; i++)
 			{
-				auto val = (long) libwps::readU16(input);
+				auto val = long(libwps::readU16(input));
 				if (val) f2 << "f" << i << "=" << std::hex << val << std::dec << ",";
 			}
 			f2 << "]" << std::dec << ",";
@@ -1292,7 +1292,7 @@ bool WPS8Parser::readFRAM(WPSEntry const &entry)
 
 	if (length < 2)
 	{
-		WPS_DEBUG_MSG(("WPS8Parser::readFRAM warning: length=0x%lx\n", (unsigned long) length));
+		WPS_DEBUG_MSG(("WPS8Parser::readFRAM warning: length=0x%lx\n", static_cast<unsigned long>(length)));
 		return false;
 	}
 
@@ -1302,7 +1302,7 @@ bool WPS8Parser::readFRAM(WPSEntry const &entry)
 	int numFram = libwps::read16(input);
 	if (numFram < 0 || numFram*2 > length)
 	{
-		WPS_DEBUG_MSG(("WPS8Parser::readFRAM warning: length=0x%lx, num=%d\n", (unsigned long) length, numFram));
+		WPS_DEBUG_MSG(("WPS8Parser::readFRAM warning: length=0x%lx, num=%d\n", static_cast<unsigned long>(length), numFram));
 		return false;
 	}
 	f << "N=" << numFram;
@@ -1374,7 +1374,7 @@ bool WPS8Parser::readFRAM(WPSEntry const &entry)
 					sizeP.setY(float(dt.m_value)/914400.f);
 					break;
 				default:
-					dim[dt.id()-8] = float(dt.m_value)/914400.f;
+					dim[dt.id()-8] = double(dt.m_value)/914400;
 					setVal[dt.id()-8] = true;
 					break;
 				}
@@ -1386,7 +1386,7 @@ bool WPS8Parser::readFRAM(WPSEntry const &entry)
 			{
 			case 0:
 			{
-				int page = (int16_t) dt.m_value;
+				int page = int16_t(dt.m_value);
 				// try to avoid creating to many page
 				if (page > lastPage+100)
 				{
@@ -1502,11 +1502,11 @@ bool WPS8Parser::readFRAM(WPSEntry const &entry)
 					ok = false;
 					break;
 				}
-				int type = m_textParser->getTextZoneType((int) dt.m_value);
+				int type = m_textParser->getTextZoneType(int(dt.m_value));
 				if ((type == 6 && frame.m_type == Frame::Header) ||
 				        (type == 7 && frame.m_type == Frame::Footer) ||
 				        (type == 5))
-					frame.m_idStrs = (int) dt.m_value;
+					frame.m_idStrs = int(dt.m_value);
 				else
 				{
 					WPS_DEBUG_MSG(("WPS8Parser::readFRAM odd id for field 0x18\n"));
@@ -1521,17 +1521,17 @@ bool WPS8Parser::readFRAM(WPSEntry const &entry)
 				break;
 			case 0x1b: // 41
 				if (frame.m_type!=Frame::Footer || dt.m_value != 0x41)
-					f2 << "##f" << dt.id() << "=" << (int16_t) dt.m_value << ",";
+					f2 << "##f" << dt.id() << "=" << int16_t(dt.m_value) << ",";
 				break;
 			case 0x26: // rotation in degree from center ( CCW)
-				f2 << "rot=" << float(dt.m_value)/10. << "deg,";
+				f2 << "rot=" << double(dt.m_value)/10. << "deg,";
 				break;
 			//
 			// Table specific field ?
 			//
 			case 0x2a:   // link to the m_idTable(ids) number for a table
 			{
-				int id = (int16_t) dt.m_value;
+				int id = int16_t(dt.m_value);
 				if (frame.m_type==Frame::Table)
 					frame.m_idTable = id;
 				else
@@ -1545,25 +1545,25 @@ bool WPS8Parser::readFRAM(WPSEntry const &entry)
 				break;
 			case 0x14: // in relation with 0x30 ? find a small number between 1 and 18
 				if (frame.m_type==Frame::Table)
-					f2 << "grpId=" << (int16_t) dt.m_value << ",";
+					f2 << "grpId=" << int16_t(dt.m_value) << ",";
 				else ok = false;
 				break;
 			case 0x30: // seems to link the table together
 				if (frame.m_type==Frame::Table)
-					f2 << "tableGrp=" << (int16_t) dt.m_value << ",";
+					f2 << "tableGrp=" << int16_t(dt.m_value) << ",";
 				else ok = false;
 				break;
 			case 0x2d: // appear 2 time in a table with value 2
-				f2 << "f" << dt.id() << "=" << (int16_t) dt.m_value << ",";
+				f2 << "f" << dt.id() << "=" << int16_t(dt.m_value) << ",";
 				break;
 
 			// UNKNOWN
 			case 0x1a: // appear 2 time (in a header and in a footer) with value 16
-				f2 << "f" << dt.id() << "=" << (int)(int8_t) dt.m_value << ",";
+				f2 << "f" << dt.id() << "=" << int(int8_t(dt.m_value)) << ",";
 				break;
 
 			case 0x2e: // in a table: objectId+1, in textbox: m_idTable ?, other = i ?
-				f2 << "id" << dt.id() << "=" << (int16_t)(dt.m_value-1) << ",";
+				f2 << "id" << dt.id() << "=" << int16_t(dt.m_value-1) << ",";
 				break;
 			case 0x13:
 				// table 0x6-??,
@@ -1587,7 +1587,7 @@ bool WPS8Parser::readFRAM(WPSEntry const &entry)
 			case 0x20: // in inches small value 0/0.05/0.1 -> a border size ?
 				bset = true;
 				bsetVal[dt.id()-0x1D] = true;
-				bDim[dt.id()-0x1D] =  float(dt.m_value)/914400.f;
+				bDim[dt.id()-0x1D] =  double(dt.m_value)/914400;
 				break;
 
 			default:
@@ -1668,7 +1668,7 @@ bool WPS8Parser::readFRCD(WPSEntry const &entry)
 
 	if (length < 4+33+5*8)
 	{
-		WPS_DEBUG_MSG(("WPS8Parser::readFRCD warning: length=0x%lx\n", (unsigned long) length));
+		WPS_DEBUG_MSG(("WPS8Parser::readFRCD warning: length=0x%lx\n", static_cast<unsigned long>(length)));
 		return false;
 	}
 	entry.setParsed();
@@ -1853,7 +1853,7 @@ bool WPS8Parser::readSYID(WPSEntry const &entry, std::vector<int> &listId)
 
 	if (length < 4)
 	{
-		WPS_DEBUG_MSG(("WPS8Parser::readSYID: warning: SYID length=0x%lx\n", (unsigned long) length));
+		WPS_DEBUG_MSG(("WPS8Parser::readSYID: warning: SYID length=0x%lx\n", static_cast<unsigned long>(length)));
 		return false;
 	}
 
@@ -1900,7 +1900,7 @@ bool WPS8Parser::readWNPR(WPSEntry const &entry)
 
 	if (length < 40)
 	{
-		WPS_DEBUG_MSG(("WPS8Parser::readWNPR: warning: WNPR length=0x%lx\n", (unsigned long) length));
+		WPS_DEBUG_MSG(("WPS8Parser::readWNPR: warning: WNPR length=0x%lx\n", static_cast<unsigned long>(length)));
 		return false;
 	}
 
@@ -1931,7 +1931,7 @@ bool WPS8Parser::readWNPR(WPSEntry const &entry)
 	f << "printmargins?=(";
 	for (int i = 0; i < 4; i++)
 	{
-		auto val = (long) libwps::readU32(input);
+		auto val = long(libwps::readU32(input));
 		long sz = dim[2+(i%2)];
 		if (sz)
 			f << float(val)/float(sz) << ",";
@@ -1950,7 +1950,7 @@ bool WPS8Parser::readWNPR(WPSEntry const &entry)
 	long actPos = input->tell();
 	if (actPos + 32*2+38+22 > endPage)
 	{
-		WPS_DEBUG_MSG(("WPS8Parser::readWNPR: length=0x%lx seems too short\n", (unsigned long) length));
+		WPS_DEBUG_MSG(("WPS8Parser::readWNPR: length=0x%lx seems too short\n", static_cast<unsigned long>(length)));
 		return false;
 	}
 
@@ -2049,7 +2049,7 @@ bool WPS8Parser::readSPELLING(RVNGInputStreamPtr input, std::string const &oleNa
 {
 	// SPELLING
 	input->seek(0, librevenge::RVNG_SEEK_SET);
-	auto vers = (int) libwps::read32(input); // always 6 ?
+	auto vers = int(libwps::read32(input)); // always 6 ?
 	if (vers < 0 || input->isEnd()) return false;
 
 	std::string fName = libwps::Debug::flattenFileName(oleName);
@@ -2065,7 +2065,7 @@ bool WPS8Parser::readSPELLING(RVNGInputStreamPtr input, std::string const &oleNa
 	while (!input->isEnd())
 	{
 		long pos = input->tell();
-		auto numVal = (int) libwps::read32(input);
+		auto numVal = int(libwps::read32(input));
 
 		if (numVal < 0 || input->seek(8*numVal, librevenge::RVNG_SEEK_CUR) || input->tell() != pos+4+8*numVal)
 		{
@@ -2087,7 +2087,7 @@ bool WPS8Parser::readSPELLING(RVNGInputStreamPtr input, std::string const &oleNa
 			}
 			else
 				id = listIds[ptr];
-			auto sPos = (long) libwps::read32(input);
+			auto sPos = long(libwps::read32(input));
 			f << std::hex << 2*sPos << ":SP" <<  std::dec << id << ",";
 		}
 		asciiFile.addPos(pos);
@@ -2097,7 +2097,7 @@ bool WPS8Parser::readSPELLING(RVNGInputStreamPtr input, std::string const &oleNa
 	f << "SPELLING:";
 	if (vers != 6) f << "version = " << vers << ", ";
 	f << "list=[";
-	for (auto it : listIds)
+	for (auto const &it : listIds)
 	{
 		uint32_t val = it.first;
 		f << "SP" << std::dec << it.second << "(" << (val&0xFF) << ":"
