@@ -318,7 +318,7 @@ bool WPS8Table::readStructures(RVNGInputStreamPtr const &input)
 {
 	m_state->m_tableMap.clear();
 
-	auto &nameTable = m_mainParser.getNameEntryMap();
+	auto const &nameTable = m_mainParser.getNameEntryMap();
 	auto pos = nameTable.lower_bound("MCLD");
 	while (pos != nameTable.end())
 	{
