@@ -45,7 +45,7 @@ namespace Debug
 //! a debug function to store in a datafile in the current directory
 //! WARNING: this function erase the file fileName if it exists
 //! (if debug_with_files is not defined, does nothing)
-bool dumpFile(librevenge::RVNGBinaryData &data, char const *fileName);
+bool dumpFile(librevenge::RVNGBinaryData const &data, char const *fileName);
 
 //! returns a file name from an ole/... name
 std::string flattenFileName(std::string const &name);
@@ -177,7 +177,7 @@ namespace libwps
 {
 namespace Debug
 {
-inline bool dumpFile(librevenge::RVNGBinaryData &, char const *)
+inline bool dumpFile(librevenge::RVNGBinaryData const &, char const *)
 {
 	return true;
 }
